@@ -1,4 +1,4 @@
-TEST_TEMPLATE="""
+
 import unittest
 
 from PROJECT_NAME.MODULE_NAME import hello
@@ -8,4 +8,3 @@ class TestHelloWorld(unittest.TestCase):
     def test_hello(self):
         self.assertEqual(hello('World'), 'Hello, World')
 
-"""
\ No newline at end of file
